.. _unit_constant:

===================
Units and constants
===================

In `sisl` values are forced to be in the following units:

====== ====
Type   Unit
====== ====
Length Ang
Energy eV
Time   ps
====== ====

More units will be added as they enter the code.
For this `sisl` requires methods to convert between different units and also
the handling of physical constants.

.. toctree::
   :maxdepth: 2

   unit_constant.unit
   unit_constant.constant

